@@ -1,6 +1,6 @@
 #include "bigint.ih"
 
-BigInt const BigInt::lshiftc() const
+BigInt BigInt::lshiftc() const
 {
     BigInt ret(*this);
     ret.lshift();
