@@ -3,7 +3,7 @@
 Log &Log::instance()
 {
     if (!s_stream.get())
-        throw Errno("Log::getInstance()") <<  ": FBB::Log not initialized";
+        throw Exception() << "Log::getInstance(): FBB::Log not initialized";
 
     return *s_stream.get();
 }
